@@ -319,26 +319,116 @@ class DataProcessingAndMessaging:
         return result
 
     # -------------------------- 发送邮件（旧版） --------------------------
-    def sende_email(self, name, contact_name, title, rec, file, cc=False, bcc=None):
-        yag = yagmail.SMTP(user='cc_yingxiao@xin.com', password='cw46pfeznNQx', host='mail.xin.com', port='587',
-                           smtp_ssl=False, smtp_starttls=True)
-        contents = f'{name} 好：\n \n ' \
-                   f'附件为{title}，请查收！\n \n' \
-                   f'如有疑问请联系{contact_name}，谢谢~'
+    def sende_email(self, name, contact_name, title, rec, file=None, cc=None, bcc=None, remarks=None):
+        """
+        简洁版邮件发送（支持重复调用，自动过滤无效参数）
+        :param name: 收件人称呼（如"各位"）
+        :param contact_name: 联系人姓名（如"董养"）
+        :param title: 邮件主题
+        :param rec: 收件人邮箱（单个字符串或列表）
+        :param file: 附件路径（单个字符串、列表，或None）
+        :param cc: 抄送邮箱（单个字符串、列表，或None）
+        :param bcc: 密送邮箱（单个字符串、列表，或None）
+        :param remarks: 附加备注（可选，默认None，传入文本字符串时追加到正文）
+        """
+
+        # 1. 内部工具：格式化邮箱（转列表+过滤无效值）
+        def format_email(emails):
+            if not emails:
+                return None
+            # 单个邮箱转列表，列表直接使用
+            email_list = [emails] if isinstance(emails, str) else emails
+            # 过滤：非空字符串 + 简单格式校验（含@和.）
+            valid_emails = [
+                e.strip() for e in email_list
+                if isinstance(e, str) and e.strip() and '@' in e.strip() and '.' in e.strip()
+            ]
+            return valid_emails if valid_emails else None
+
+        # 2. 格式化所有邮箱参数
+        to_emails = format_email(rec)
+        cc_emails = format_email(cc)
+        bcc_emails = format_email(bcc)
+
+        # 3. 核心参数校验（提前报错，避免无效连接）
+        if not to_emails:
+            err_msg = "邮件发送失败：无有效收件人邮箱"
+            self.logger.error(err_msg)
+            raise ValueError(err_msg)
+        if not title.strip():
+            err_msg = "邮件发送失败：邮件主题不能为空"
+            self.logger.error(err_msg)
+            raise ValueError(err_msg)
+
+        # 4. 附件处理（校验存在性，支持单个/列表）
+        attachments = None
+        if file:
+            file_list = [file] if isinstance(file, str) else file
+            attachments = []
+            for f in file_list:
+                f = f.strip()
+                if not os.path.exists(f):
+                    err_msg = f"邮件发送失败：附件不存在 -> {f}"
+                    self.logger.error(err_msg)
+                    raise FileNotFoundError(err_msg)
+                attachments.append(f)
+
+        # 5. SMTP固定配置（重复调用无需修改）
+        smtp_conf = {
+            "user": 'cc_yingxiao@xin.com',
+            "password": 'cw46pfeznNQx',
+            "host": 'mail.xin.com',
+            "port": 587,
+            "smtp_ssl": False,
+            "smtp_starttls": True
+        }
+
+        # 6. 邮件内容（新增remarks逻辑：有值则追加到"请查收！"下方，保持缩进一致）
+        email_content = f"{name} 好：\n附件为《{title}》，请查收！"
+        if remarks and isinstance(remarks, str) and remarks.strip():
+            formatted_remarks = remarks.strip().replace('\n', '\n')  # 处理多行备注
+            email_content += f"\n{formatted_remarks}"
+        email_content += f"\n\n如有疑问请联系{contact_name}，谢谢~"
+
         try:
-            if cc and bcc:
-                yag.send(rec, title, contents, file, cc, bcc)
-            elif cc:
-                yag.send(rec, title, contents, file, cc)
-            elif bcc:
-                yag.send(rec, title, contents, file, bcc)
-            else:
-                yag.send(rec, title, contents, file)
-            self.logger.info(f'邮件主题：{title} \n邮件附件：{file} 发送完成')
-            print(f'邮件主题：{title} \n邮件附件：{file} 发送完成')
+            # 上下文管理器：自动关闭连接，重复调用不泄露资源
+            with yagmail.SMTP(**smtp_conf) as yag:
+                yag.send(
+                    to=to_emails,
+                    subject=title.strip(),
+                    contents=email_content,
+                    attachments=attachments,
+                    cc=cc_emails,
+                    bcc=bcc_emails
+                )
+            # 简洁日志：关键信息+统计，便于排查
+            log_msg = f"邮件发送成功 | 主题：{title.strip()} | 收件人：{len(to_emails)}人"
+            if cc_emails:
+                log_msg += f" | 抄送：{len(cc_emails)}人"
+            if bcc_emails:
+                log_msg += f" | 密送：{len(bcc_emails)}人"
+            if attachments:
+                log_msg += f" | 附件：{len(attachments)}个"
+            if remarks and remarks.strip():
+                log_msg += f" | 包含备注：{remarks.strip()[:20]}..."  # 日志显示备注前20字（避免过长）
+            self.logger.info(log_msg)
+            print(log_msg)
+
+        # 7. 分类异常捕获（易排查问题）
+        except yagmail.SMTPAuthenticationError:
+            err_msg = "邮件发送失败：SMTP账号/密码/授权码错误"
+            self.logger.error(err_msg)
+            raise ValueError(err_msg)
+        except yagmail.SMTPConnectionError:
+            err_msg = "邮件发送失败：SMTP服务器连接失败（检查host/port/防火墙）"
+            self.logger.error(err_msg)
+            raise ConnectionError(err_msg)
+        except FileNotFoundError:
+            raise  # 附件错误已提前处理，直接抛出
         except Exception as e:
-            self.logger.error(f"邮件发送失败: {str(e)}", exc_info=True)
-            raise
+            err_msg = f"邮件发送失败：{str(e)}"
+            self.logger.error(err_msg, exc_info=True)
+            raise RuntimeError(err_msg)
 
     # 新增：提取Hive核心错误信息方法
     def extract_core_hive_error(self, err_msg):
@@ -798,7 +888,7 @@ class DataProcessingAndMessaging:
                     worksheet.write(row, col, value, data_format)
 
         worksheet.freeze_panes(1, 0)
-        worksheet.autofilter(0, 0, max_row, max_col)
+        worksheet.autofilter(0, 0, max_row, max_col - 1)  # 修正：结束列=max_col-1（比如2）
 
     # -------------------------- 导出DataFrame到Excel --------------------------
     def export_df_to_excel(self, df_list, sheet_names, file_path):
@@ -938,8 +1028,9 @@ class DataProcessingAndMessaging:
                 self._wechat_doc_log(error_msg)
                 raise Exception(error_msg)
             docid = result.get("docid")
-            self._wechat_doc_log(f"创建成功：docid={docid}")
-            return {"docid": docid, "url": result.get("url")}
+            self._wechat_doc_log(f"智能表格：{sheet_name} 创建成功，docid={docid}")
+            print(f"智能表格：{sheet_name} 创建成功，docid={docid}")
+            return {"智能表格": sheet_name, "docid": docid, "url": result.get("url")}
         except Exception as e:
             self._wechat_doc_log(f"创建异常: {str(e)}")
             raise
@@ -1119,6 +1210,7 @@ class DataProcessingAndMessaging:
             raise Exception(error_msg)
 
         self._wechat_doc_log(f"文档删除成功：docid={docid}")
+        print(f"文档删除成功：docid={docid}")
         return True
 
     # -------------------------- 辅助方法：检查文件是否被占用 --------------------------
